@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 RSpec.describe('Escape scanning') do
@@ -76,7 +78,7 @@ b/x,                                          0 => [:literal,  :literal,
   # In Regexp literals, these escapes are now pre-processed to hex escapes.
   #
   # https://github.com/ruby/ruby/commit/11ae581a4a7f5d5f5ec6378872eab8f25381b1b9
-  n = ->(regexp_body){ Regexp.new(regexp_body.force_encoding('ascii-8bit')) }
+  n = ->(regexp_body){ Regexp.new(regexp_body.dup.force_encoding('ascii-8bit')) }
 
   include_examples 'scan', 'a\cBc',           1 => [:escape,  :control,          '\cB',            1,  4]
   include_examples 'scan', 'a\c^c',           1 => [:escape,  :control,          '\c^',            1,  4]
